@@ -10,16 +10,16 @@ require HTTP::Request::Common;
 require Crypt::SSLeay;
 require Exporter;
 
-our $VERSION = "1.06.1";
+our $VERSION = "1.01";
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = ();
 our @EXPORT = ();
 
-our $USER_AGENT = "User-Agent: Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.8) Gecko/20050511 Firefox/1.0.4";
-our $MAIL_URL = "http://mail.google.com/mail";
-our $SSL_MAIL_URL = "https://mail.google.com/mail";
-our $LOGIN_URL = "https://www.google.com/accounts/ServiceLoginBoxAuth";
+our $USER_AGENT = "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7) Gecko/20040626 Firefox/0.8";
+our $MAIL_URL = "http://gmail.google.com/gmail";
+our $SSL_MAIL_URL = "https://gmail.google.com/gmail";
+our $LOGIN_URL = "https://www.google.com/accounts/ServiceLoginBoxAuth?service=mail&continue=http://gmail.google.com/gmail";
 
 our %FOLDERS = (
     'INBOX'   => '^I',
@@ -33,19 +33,16 @@ sub new {
     my %args = @_;
 
     my $ua = new LWP::UserAgent( agent => $USER_AGENT, keep_alive => 1 );
-    $ua->timeout( $args{timeout} ) if defined $args{timeout};
-
     push( @LWP::Protocol::http::EXTRA_SOCK_OPTS, SendTE => 0 );
     
     my $self = bless {
-        _username      => $args{username}       || die( 'No username defined' ),
-        _password      => $args{password}       || die( 'No password defined' ),
-        _login_url     => $args{login_server}   || $LOGIN_URL,
-        _mail_url      => $args{mail_server}    || $args{encrypt_session} ? $SSL_MAIL_URL : $MAIL_URL,
-        _proxy_user    => $args{proxy_username} || '',
-        _proxy_pass    => $args{proxy_password} || '',
-        _proxy_name    => $args{proxy_name}     || '',
-        _proxy_enable  => 0,
+        _username      => $args{username}      || die( 'No username defined' ),
+        _password      => $args{password}      || die( 'No password defined' ),
+        _login_url     => $args{login_server}  || $LOGIN_URL,
+        _mail_url      => $args{mail_server}   || $args{encrypt_session} ? $SSL_MAIL_URL : $MAIL_URL,
+        _proxy_user    => $args{proxy_username}|| '',
+        _proxy_pass    => $args{proxy_password}|| '',
+        _proxy_name    => $args{proxy_name}    || '',
         _logged_in     => 0,
         _err_str       => '',
         _cookies       => { },
@@ -92,72 +89,62 @@ sub login {
     }
 
     my $req = HTTP::Request->new( POST => $self->{_login_url} );
-    $req->header( 'Cookie' => $self->{_cookie} );
     my ( $cookie );
 
     $req->content_type( "application/x-www-form-urlencoded" );
-    $req->content( 'Email=' . $self->{_username} . '&Passwd=' . $self->{_password} . '&null=Sign+in' );
-
+    $req->content( 'Email=' . $self->{_username} . '&Passwd=' . $self->{_password} . '&null=Sign%20in' );
     my $res = $self->{_ua}->request( $req );
 
-    if ( !$res->is_success() ) {
-        $self->{_error} = 1;
-        $self->{_err_str} .= "Error: Could not login with those credentials - the request was not a success\n";
-        $self->{_err_str} .= "  Additionally, HTTP error: " . $res->status_line . "\n";
-        return;
-    }
-
-    update_tokens( $self, $res );
-    if ( $res->content() !~ /var url = "(.*?)"/ ) {
-        $self->{_error} = 1;
-        $self->{_err_str} .= "Error: Could not login with those credentials - could not find final URL\n";
-        $self->{_err_str} .= "  Additionally, HTTP error: " . $res->status_line . "\n";
-        return;
-    }
-
-    my $final_url;
-    ( $final_url = $1 ) =~ s/\\u003d/=/;
-
-    $req = HTTP::Request->new( GET => $final_url );
-    $req->header( 'Cookie' => $self->{_cookie} );
-    $res = $self->{_ua}->request( $req );
-    if ( ( $res->content() !~ /<a href="http:\/\/mail\.google\.com\/mail\?view=(?:.*?)&amp;fs=(?:.*?)" target="_blank"> (?:.*?) <\/a>/ ) &&
-       ( $res->content() !~ /<a href="http:\/\/mail\.google\.com\/mail">(?:.*?)<\/a>/ ) ) {
-        $self->{_error} = 1;
-        $self->{_err_str} .= "Error: Could not login with those credentials - could not find Gmail account.\n";
-        $self->{_err_str} .= "  Additionally, HTTP error: " . $res->status_line . "\n";
-        return;
-    }
-    update_tokens( $self, $res );
-
-    $req = HTTP::Request->new( GET => 'http://mail.google.com/mail?view=pr&amp;fs=1' );
-    $req->header( 'Cookie' => $self->{_cookie} );
-    $res = $self->{_ua}->request( $req );
-    if ( $res->content() !~ /top.location="(.*?)"/ ) {
-        $self->{_error} = 1;
-        $self->{_err_str} .= "Error: Could not login with those credentials - could not find 'top.location'\n";
-        $self->{_err_str} .= "  Additionally, HTTP error: " . $res->status_line . "\n";
-        return;
-    }
-    update_tokens( $self, $res );
-
-    $final_url = ( URI::Escape::uri_unescape( $1 ) );
-    if ( $self->{_proxy_enable} ) {
-        if ( $self->{_proxy_enable} >= 1 ) {
-            $self->{_ua}->proxy( 'http', $self->{_proxy_name} );
-            delete ( $ENV{HTTPS_PROXY} );
-        }
-        if ( $self->{_proxy_enable} >= 2 ) {
-            delete ( $ENV{HTTPS_PROXY_USERNAME} );
-            delete ( $ENV{HTTPS_PROXY_PASSWORD} );
+    if ( $res->is_success() ) {
+        update_tokens( $self, $res );
+        if ( $res->content() =~ /top.location = "(.*)";/ ) {
+            $req = HTTP::Request->new( GET => "https://www.google.com/accounts/$1" );
+            $req->header( 'Cookie' => $self->{_cookie} );
+            $res = $self->{_ua}->request( $req );
+            if ( $res->content() =~ /location.replace\("(.*)"\)/ ) {
+                update_tokens( $self, $res );
+                $req = HTTP::Request->new( GET => $1 );
+                $req->header( 'Cookie' => $self->{_cookie} );
+                $res = $self->{_ua}->request( $req );
+                if ( $res->content() =~ /frame name=js src=\/gmail(.*?) / ) {
+                    update_tokens( $self, $res );
+                    if ( $self->{_proxy_enable} ) {
+                        if ( $self->{_proxy_enable} >= 1 ) {
+                            $self->{_ua}->proxy( 'http', $self->{_proxy_name} );
+                            delete ( $ENV{HTTPS_PROXY} );
+                        }
+                        if ( $self->{_proxy_enable} >= 2 ) {
+                            delete ( $ENV{HTTPS_PROXY_USERNAME} );
+                            delete ( $ENV{HTTPS_PROXY_PASSWORD} );
+                        }
+                    }
+                    $self->{_logged_in} = 1;
+                    get_page( $self, start => '', search => '', view => '', req_url => $self->{_mail_url} . $1 );                  
+                    return( 1 );
+                } else {
+                    $self->{_error} = 1;
+                    $self->{_err_str} .= "Error: Could not login with those credentials\n";
+                    $self->{_err_str} .= "  Additionally, HTTP error: " . $res->status_line . "\n";
+                    return;
+                }
+            } else {
+                $self->{_error} = 1;
+                $self->{_err_str} .= "Error: Could not login with those credentials\n";
+                $self->{_err_str} .= "  Additionally, HTTP error: " . $res->status_line . "\n";
+                return;
+            }
+        } else {
+            $self->{_error} = 1;
+            $self->{_err_str} .= "Error: Could not login with those credentials\n";
+            $self->{_err_str} .= "  Additionally, HTTP error: " . $res->status_line . "\n";
+            return;
         }
+    } else {
+        $self->{_error} = 1;
+        $self->{_err_str} .= "Error: Could not login with those credentials\n";
+        $self->{_err_str} .= "  Additionally, HTTP error: " . $res->status_line . "\n";
+        return;
     }
-
-    $self->{_logged_in} = 1;
-    $res = get_page( $self, search => '', start => '', view => '', req_url => $final_url );
-    $res = get_page( $self, search => 'inbox' );
-
-    return ( 1 );
 }
 
 sub check_login {
@@ -212,7 +199,7 @@ sub get_page {
         method  => '',
         req_url => $self->{_mail_url},
         @_, );
-    my ( $res, $req, $req_url, @tees );
+    my ( $res, $req, $req_url );
 
     unless ( check_login( $self ) ) { return };
 
@@ -227,16 +214,6 @@ sub get_page {
         }
     }
 
-    if ( defined( $args{ 't' } ) ) {
-        if ( ref( $args{ 't' } ) eq 'ARRAY' ) {
-            foreach ( @{ $args{ 't' } } ) {
-                push( @tees, 't' );
-                push( @tees, $_ );
-            }
-            delete( $args{ 't' } );
-        }
-    }
-
     $req_url = $args{ 'req_url' };
     delete( $args{ 'req_url' } );
 
@@ -266,7 +243,7 @@ sub get_page {
             Connection   => 'Keep-Alive',
             'Keep-Alive' => 300,
             Cookie       => $self->{_cookie},
-            Content      => [ view => $view, %args, @tees ] );
+            Content      => [ view => $view, %args ] );
         if ( $self->{_proxy_enable} && $self->{_proxy_enable} >= 2 ) {
             $req->proxy_authorization_basic( $self->{_proxy_user}, $self->{_proxy_pass} );
         }
@@ -354,16 +331,16 @@ sub edit_labels {
 
     my $action;
 
-    if ( uc( $args{ 'action' } ) eq 'CREATE' ) {
+    if ( $args{ 'action' } eq 'create' ) {
         $action = 'cc_';
         $args{ 'new_name' } = '';
-    } elsif ( uc( $args{ 'action' } ) eq 'DELETE' ) {
+    } elsif ( $args{ 'action' } eq 'delete' ) {
         $action = 'dc_';
         $args{ 'new_name' } = '';
-    } elsif ( uc( $args{ 'action' } ) eq 'REMOVE' ) {
+    } elsif ( $args{ 'action' } eq 'remove' ) {
         $action = 'rc_';
         $args{ 'new_name' } = '';
-    } elsif ( uc( $args{ 'action' } ) eq 'ADD' ) {
+    } elsif ( $args{ 'action' } eq 'add' ) {
         $action = 'ac_';
         $args{ 'new_name' } = '';
         unless ( defined( $args{ 'msgid' } ) ) {
@@ -373,9 +350,10 @@ sub edit_labels {
         } else {
             $args{ 't' } = $args{ 'msgid' };
             delete( $args{ 'msgid' } );
+            $args{ 'method' } = 'get';
             $args{ 'search' } = 'all';
         }
-    } elsif ( uc( $args{ 'action' } ) eq 'RENAME' ) {
+    } elsif ( $args{ 'action' } eq 'rename' ) {
         $args{ 'new_name' } = '^' . validate_label( $self, $args{ 'new_name' } );
         if ( $self->{_error} ) {
             return;
@@ -691,7 +669,6 @@ sub send_message {
 sub get_messages {
     my ( $self ) = shift;
     my ( %args ) = (
-        init    => 1,
         start => 0,
         @_, );
     my ( $res, $req );
@@ -731,12 +708,10 @@ sub get_messages {
             $indv_email{ 'starred' }       = remove_quotes( $email_line[2] );
             $indv_email{ 'date_received' } = remove_quotes( $email_line[3] );
             $indv_email{ 'sender_email' }  = remove_quotes( $email_line[4] );
-                $indv_email{ 'sender_email' } =~ /\\"(.*?)\\">/;
-                $1 =~ /_(?:.*?)_(.*?)$/;
-                $indv_email{ 'sender_email' } = $1;
-            $indv_email{ 'sender_name' }   = remove_quotes( $email_line[4] );
-                $indv_email{ 'sender_name' } =~ />(?:<b>)?(.*?)<\//;
-                $indv_email{ 'sender_name' } = $1;
+                $indv_email{ 'sender_email' } =~ /'\\>(.*?)\\/;
+            $indv_email{ 'sender_name' }   = remove_quotes( $1 );
+                $indv_email{ 'sender_email' } =~ /_user_(.*?)\\/;
+                $indv_email{ 'sender_email' } = remove_quotes( $1 );
             $indv_email{ 'subject' }       = remove_quotes( $email_line[6] );
             $indv_email{ 'blurb' }         = remove_quotes( $email_line[7] );
             $indv_email{ 'labels' } = [ map{ remove_quotes( $_ ) }@{ extract_fields( $email_line[8] ) } ];
@@ -744,7 +719,7 @@ sub get_messages {
             $indv_email{ 'attachments' } = extract_fields( $email_line[9] ) if ( $email_line[9] ne '' );
             push ( @emails, \%indv_email );
         }
-        if ( ( @emails == @{ $functions{ 'ts' } }[1] ) && ( @{ $functions{ 'ts' } }[0] != @{ $functions{ 'ts' } }[2] ) ) {
+        if ( @emails == @{ $functions{ 'ts' } }[1] ) {
             my $start = $args{ 'start' };
             delete( $args{ 'start' } );
             if ( $args{ 'cat' } ) {
@@ -752,10 +727,7 @@ sub get_messages {
                 delete ( $args{ 'cat' } );
                 delete ( $args{ 'search' } );
             }
-            my $next_page_emails = get_messages( $self, start => ( $start + @emails ), %args );
-            if ( $next_page_emails ) {
-                @emails = ( @emails, @{ $next_page_emails } );
-            }
+            @emails = ( @emails, @{ get_messages( $self, start => ( $start + @emails ), %args ) } );
         }
         return ( \@emails );
     } else {
@@ -845,7 +817,7 @@ sub delete_message {
 sub get_indv_email {
     my ( $self ) = shift;
     my ( %args ) = (
-        view   => 'cv',
+        view   => 'pt',
         @_, );
 
     if ( defined( $args{ 'id' } ) && defined( $args{ 'label' } ) ) {
@@ -908,7 +880,7 @@ sub get_indv_email {
                 my @email = @{ extract_fields( $_ ) };
                 $email[2] = remove_quotes( $email[2] );
                 if ( $email[16] ne '' ) {
-                    my @attachments = @{ extract_fields( $email[17] ) };
+                    my @attachments = @{ extract_fields( $email[16] ) };
                     my @files;
                     foreach ( @attachments ) {
                         my @attachment = @{ extract_fields( $_ ) };
@@ -922,11 +894,11 @@ sub get_indv_email {
                     $message{ 'attachments' } = \@files;
                 }
                 $message{ 'id' }      = $email[2];
-                $message{ 'sender' }  = remove_quotes( $email[7] );
-                $message{ 'sent' }    = remove_quotes( $email[9] );
-                $message{ 'to' }      = remove_quotes( $email[10] );
-                $message{ 'read' }    = remove_quotes( $email[14] );
-                $message{ 'subject' } = remove_quotes( $email[15] );
+                $message{ 'sender' }  = remove_quotes( $email[6] );
+                $message{ 'sent' }    = remove_quotes( $email[8] );
+                $message{ 'to' }      = remove_quotes( $email[9] );
+                $message{ 'read' }    = remove_quotes( $email[13] );
+                $message{ 'subject' } = remove_quotes( $email[14] );
                 if ( $args{ 'th' } eq $email[2] ) {
                     foreach ( @{ $functions{ 'mb' } } ) {
                         my $body = extract_fields( $_ );
@@ -1075,79 +1047,37 @@ sub get_ads {
 
     unless ( check_login( $self ) ) { return };
 
-    if ( defined( $args{ 'adkey' } ) ) {
-        $args{ 'bb' } = $args{ 'adkey' };
-        delete( $args{ 'adkey' } );
-    } else {
-        $self->{_error} = 1;
-        $self->{_err_str} .= "Error: No addkey provided.\n";
-        return;
-    }
-
-    my $res = get_page( $self, %args );
-    if ( $res->is_success() ) {
-        my $ad_text = $res->content();
-        $ad_text =~ s/\n//g;
-        $ad_text =~ /\[(\[.*?\])\]/;
-        $ad_text = $1;
-        my @indv_ads = @{ extract_fields( $ad_text ) };
-        my @ads;
-        foreach ( @indv_ads ) {
-            my @split_ad = @{ extract_fields( $_ ) };
-            if ( uc( remove_quotes( $split_ad[0] ) ) eq 'A' ) {
-                $split_ad[5] =~ s/<wbr>.*//i;
+    if ( $args{ 'adkey' } ne '' ) {
+        my $res = get_page( $self, %args );
+        if ( $res->is_success() ) {
+            my $ad_text = $res->content();
+            $ad_text =~ s/\n//g;
+            $ad_text =~ /\[\[(.*?)\]\],/;
+            $ad_text = $1;
+            my @indv_ads = @{ extract_fields( $ad_text ) };
+            my @ads;
+            foreach ( @indv_ads ) {
+                my @split_ad = @{ extract_fields( $_ ) };
                 my %ad_hash = (
-                    title       => remove_quotes( $split_ad[2] ),
-                    body        => remove_quotes( $split_ad[3] ),
-                    vendor_link => remove_quotes( $split_ad[5] ),
-                    link        => remove_quotes( $split_ad[4] ), );
-                push( @ads, \%ad_hash );
-            } elsif ( uc( remove_quotes( $split_ad[0] ) ) eq 'RN' ) {
-                if ( $split_ad[3] =~ /redir_url=(.*?)\"/ ) {
-                    my $vendor_link = $1;
-                    my %ad_hash = (
-                        title       => remove_quotes( $split_ad[1] ),
-                        body        => remove_quotes( $split_ad[2] ),
-                        vendor_link => url_unencode( $self, url => $vendor_link ),
-                        link        => remove_quotes( $split_ad[3] ), );
-                    push( @ads, \%ad_hash );
-                }
-            } elsif ( uc( remove_quotes( $split_ad[0] ) ) eq 'RP' ) {
-                my %ad_hash = (
-                    title       => remove_quotes( $split_ad[1] ),
-                    body        => remove_quotes( $split_ad[2] ),
-                    vendor_link => remove_quotes( $split_ad[4] ),
+                    title       => remove_quotes( $split_ad[0] ),
+                    body        => remove_quotes( $split_ad[1] ),
+                    vendor_link => remove_quotes( $split_ad[2] ),
                     link        => remove_quotes( $split_ad[3] ), );
                 push( @ads, \%ad_hash );
             }
+            return( \@ads );
+        } else {
+            $self->{_error} = 1;
+            $self->{_err_str} .= "Error: " . $res->status_line();
         }
-
-        return( \@ads );
     } else {
         $self->{_error} = 1;
-        $self->{_err_str} .= "Error: " . $res->status_line();
+        $self->{_err_str} .= "Error: Must send adkey.\n";
     }
 
     return;
 }
 
-sub url_unencode {
-    my $self = shift;
-    my ( %args ) = (
-        url => '',
-        @_,
-    );
-
-    if ( $args{ 'url' } ) {
-        $args{ 'url' } =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack( "C", hex( $1 ) )/eg;
-        return( $args{ 'url' } );
-    } else {
-        $self->{_error} = 1;
-        $self->{_err_str} .= "Error: Must supply URL to unencode.";
-        return;
-    }
-}
-
 sub get_attachment {
     my ( $self ) = shift;
     my ( %args ) = (
@@ -1380,8 +1310,7 @@ sub extract_fields {
         if ( $end_field ) {
             if ( $field ne '' ) {
                 push ( @fields, $field );
-            }
-            $field = '';
+            }            $field = '';
             $end_field = 0;
         }
     }
@@ -1716,18 +1645,6 @@ To permanently delete a message, just send a msgid
 
     $gmail->delete_message( msgid => $msgid );
 
-=head2 ACTING ON MULTIPLE MESSAGES
-
-To act on multiple messages at once send an array ref containing all of the message IDs you with to act on.  This is useful because
-Gmail may temporarily ban you if you send too much traffic in a short amount of time (for instance deleting all of the messaging in
-your SPAM folder one at a time).
-
-    ### Delete Many Messages at once ###
-    $gmail->delete_message( msgid => \@msgids, search => 'spam', del_message => 1 );
-
-    ### Applying a label to multiple messages at once ###
-    $gmail->edit_labels( label => 'label_name', action => 'add', msgid => \@msgids );
-
 =head2 GETTING ATTACHMENTS
 
 There are two ways to get an attachment:
@@ -1811,9 +1728,9 @@ SAMPLE USAGE
             username => 'username', password => 'password', );
 
     ### Test Sending Message ####
-    my $msgid = $gmail->send_message( to => 'mincus@gmail.com', subject => time(), msgbody => 'Test' );
+    my $msgid = $gmail->send_message( to => 'testuser@test.com', subject => time(), msgbody => 'Test' );
+    print "Msgid: $msgid\n";
     if ( $msgid ) {
-        print "Msgid: $msgid\n";
         if ( $gmail->error() ) {
             print $gmail->error_msg();
         } else {
@@ -1832,10 +1749,6 @@ SAMPLE USAGE
                 }
             }
         }
-    } else {
-        if ( $gmail->error() ) {
-            print $gmail->error_msg();
-        }
     }
     ###
 
@@ -1856,43 +1769,28 @@ SAMPLE USAGE
     ### Delete all SPAM folder messages ###
     my $messages = $gmail->get_messages( label => $Mail::Webmail::Gmail::FOLDERS{ 'SPAM' } );
     if ( @{ $messages } ) {
-        my @msgids;
         foreach ( @{ $messages } ) {
-            push( @msgids, $_->{ 'id' } );
+            $gmail->delete_message( msgid => $_->{ 'id' }, search => 'spam', del_message => 1 );
+            if ( $gmail->error() ) {
+                print $gmail->error_msg();
+            } else {
+                print "MSG: " . $_->{ 'id' } . " deleted\n";
+            }
         }
-        $gmail->delete_message( msgid => \@msgids, search => 'spam', del_message => 1 );
-        if ( $gmail->error() ) {
-            print $gmail->error_msg();
-        } else {
-            print "Deleted " . @msgids . " Messages\n";
-        }
     }
     ###
 
-    ### Print out all user defined labels
+    ### Prints out new messages attached to the first label
     my @labels = $gmail->get_labels();
-    foreach ( @labels ) {
-        print "Label: '" . $_ . "'\n";
-    }
-    ###
+
+    my $messages = $gmail->get_messages( label => $labels[0] );
 
-    ### Prints out all _New_ messages attached to the first label
-    my @labels = $gmail->get_labels();
-    unless ( $gmail->error() ) {
-        my $messages = $gmail->get_messages( label => $labels[0] );
-        unless( $gmail->error() ) {
-            if ( defined( $messages ) ) {
-                foreach ( @{ $messages } ) {
-                    if ( $_->{ 'new' } ) {
-                        print "Subject: " . $_->{ 'subject' } . " / Blurb: " . $_->{ 'blurb' } . "\n";
-                    }
-                }
+    if ( defined( $messages ) ) {
+        foreach ( @{ $messages } ) {
+            if ( $_->{ 'new' } ) {
+                print "Subject: " . $_->{ 'subject' } . " / Blurb: " . $_->{ 'blurb' } . "\n";
             }
-        } else {
-            print $gmail->error_msg();
         }
-    } else {
-        print $gmail->error_msg();
     }
     ###
 
@@ -1915,13 +1813,14 @@ SAMPLE USAGE
     ### Prints out the vendor link from Ads attached to a message
     my $messages = $gmail->get_messages( label => $Mail::Webmail::Gmail::FOLDERS{ 'INBOX' } );
 
+    print @{ $messages } . "\n";
     foreach ( @{ $messages } ) {
         print "ID: " . $_->{ 'id' } . "\n";
         my %email = %{ $gmail->get_indv_email( msg => $_ ) };
         if ( $email{ $_->{ 'id' } }->{ 'ads' } ) {
             my $ads;
             foreach $ads ( @{ $email{ $_->{ 'id' } }->{ 'ads' } } ) {
-                print " - AD LINK: $ads->{vendor_link}\n";
+                print "AD LINK: $ads->{vendor_link}\n";
             }
         }
     }
@@ -1979,33 +1878,15 @@ SAMPLE USAGE
     }
     ###
 
-    ### Print out space remaining in mailbox
-    my $remaining = $gmail->size_usage();
-    print "Remaining: '" . $remaining . "'\n";
-    ###
-
 =head1 AUTHOR INFORMATION
 
 Copyright 2004-2005, Allen Holman.  All rights reserved.  
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-Address bug reports and comments to: 
-email: mincus \at cpan \. org
-AIM: mincus c03
-Website: http://code.mincus.com
+Address bug reports and comments to: mincus \at cpan \. org.  Or through
+AIM at mincus c03.
 
 When sending bug reports, please provide the version of Gmail.pm, the version of
 Perl and the name and version of the operating system you are using. 
